@@ -1,6 +1,5 @@
-from PyObjCTools.TestSupport import *
-
 import StoreKit
+from PyObjCTools.TestSupport import TestCase, min_os_level, expectedFailure
 
 
 class TestSKArcadeService(TestCase):
@@ -12,7 +11,6 @@ class TestSKArcadeService(TestCase):
             b"v@I@I@",
         )
 
-
     @min_os_level("10.15")
     @expectedFailure
     def test_methods10_15_missing(self):
@@ -21,7 +19,3 @@ class TestSKArcadeService(TestCase):
             2,
             b"v@I@I@",
         )
-
-
-if __name__ == "__main__":
-    main()
