@@ -1,6 +1,5 @@
-from PyObjCTools.TestSupport import *
-
-import StoreKit
+import StoreKit  # noqa: F401
+from PyObjCTools.TestSupport import TestCase
 import objc
 
 
@@ -9,7 +8,3 @@ class TestSKRequest(TestCase):
         self.assertIsInstance(
             objc.protocolNamed("SKRequestDelegate"), objc.formal_protocol
         )
-
-
-if __name__ == "__main__":
-    main()
